<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE" sourcelanguage="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Basis-Downloader</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Liste holen</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Eingabe der URL:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Formatcode</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Erweiterung</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Tool zum Herunterladen:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Inhalt der Zwischenablage einfügen</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Kürzlich verwendet</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Batch-Downloader</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Vorschaubild</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>Url zum Herunterladen</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>URL aus Zwischenablage einfügen</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Monitor Zwischenablage für Url</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Url zur Liste hinzufügen</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Einstellen</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Downloader Wiedergabeliste</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Download-Optionen:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>Eingabe der URL-Wiedergabeliste:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Lösche interne Archivdatei</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Verwende Interne Archivdatei</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothek</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Auffrischen</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Öffne Ordner</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Startseite</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Allgemeine Optionen</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Tray-Symbol anzeigen</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Speichere automatisch die Liste der nicht heruntergeladenen Medien</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Option auf Standardwerte zurücksetzen</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Standardeinstellungen festlegen</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Voreingestellte Optionen</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Download-Pfad</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Sprache auswählen</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Download-Tools Standardoptionen</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Listenoptionen abrufen:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonnements</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Ui-Name</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Aktivieren der Registerkarte &quot;Bibliothek&quot;</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Textkodierung</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Download-Tools Name</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Optionen zum Hinzufügen</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Url-Verwaltung</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Download Optionen</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Festlegen, welche Url von welchem Download-Tools verwaltet werden soll</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Url-Filter</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation type="unfinished">Kopiere Url</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Speichere in Dateiliste</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Antworten an</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Speichere Untertitel in Datei</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Download-Tool Name:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Liste aus Datei holen</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Voreingestellte Optionen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Öffne Download-Ordner</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Urheberrecht</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Qt-Version</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Dieses Programm ist freie Software; Sie können es unter den Bedingungen der GNU General Public License, wie sie von der Free Software Foundation veröffentlicht wurde, weitergeben und/oder modifizieren; entweder unter Version 2 der Lizenz oder (nach Ihrer Wahl) einer späteren Version.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Dieses Programm wird in der Hoffnung verteilt, dass es nützlich ist, aber OHNE JEGLICHE GARANTIE; sogar ohne die stillschweigende Garantie der HANDELSÜBLICHKEIT oder der EIGNUNG FÜR EINEN BESTIMMTEN ZWECK. Siehe die GNU General Public License für weitere Details.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Polnisch (Polen)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Englisch (US)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Spanisch (Spanien)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Chinesisch (China)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Türkisch (Türkei)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Russisch (Russland)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Japanisch (Japan)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Französisch (Frankreich)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Italienisch (Italien)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Schwedisch (Schweden)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Fehler, ausführbare Datei zum Backend &quot;%1&quot; konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Download-Tool &quot;%1&quot; erfordert mindestens Version &quot;%2&quot; von Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Um diese Prüfungen zu deaktivieren, gehen Sie wie folgt vor:-</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Gehen Sie zur Registerkarte &quot;Konfigurieren&quot;.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Gehen Sie zu &quot;Allgemeine Optionen&quot; Unterregisterkarte.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Fehler, die Konfigurationsdatei &quot;%1&quot; konnte nicht geparst werden;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Ein Plugin konnte nicht geladen werden</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Die ausführbare Datei &quot;%1&quot; konnte nicht gefunden werden;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Die ausführbare Datei python3 für das Backend &quot;%1&quot; konnte nicht gefunden werden;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Download abgebrochen</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Format-Code</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Erweiterungen</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Datei konnte nicht zum Schreiben geöffnet werden</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Datei konnte nicht zum Lesen geöffnet werden</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Verstrichene Zeit:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Es konnten keine Versionsinformationen gefunden werden, stellen Sie sicher, dass &quot;%1&quot; installiert ist und ordnungsgemäß funktioniert</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Gefundene Version</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Netzwerk hat nicht innerhalb von %1 Sekunden geantwortet</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Der Download ist fehlgeschlagen, der folgende Pfad kann nicht erstellt werden: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Herunterladen starten</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Download Fehlgeschlagen</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Parsen der json-Datei von Github fehlgeschlagen</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Herunterladen von</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Downloadverzeichnis</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Herunterladen abgeschlossen</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Archiv extrahieren: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Verarbeitung</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Herunterladen abgeschlossen</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Setze Download-Ordner auf Standard zurück</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Nachbearbeitung</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Erzwinge Herunterladen</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Log-Fenster anzeigen</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Upload-Datum:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Dauer:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Name des Untertitels</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Optionen zum Herunterladen</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Zusätzliche Optionen zum Herunterladen</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Download Zeitintervall</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Bereits archivierte Medien</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Verbleibende Zeit</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Heruntergeladen</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Das kann sehr lange dauern</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Geschwindigkeit:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; or &quot;unzip&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Batch-Datei festlegen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Herunterladen von Kommentaren</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Kopiere Url</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Zeige Untertitel</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Zeige Kommentare</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Zeige Medienoptionen</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Medienteil herunterladen</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Einstellen</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Herunterladen von Untertiteln</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Als Standard festlegen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Eine Engine-Datei auswählen</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Download-Ordner festlegen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Hinzufügen</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation type="unfinished">Standardeinstellungen festlegen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Lösche alles</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Log-Fenster</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Bereinigen</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Listenoptionen abrufen:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Kopiere Url</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Zeige Kommentare</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Alle Aktualisierungen anzeigen</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Alle Aktualisierungen herunterladen</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Abos verwalten</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Anzahl der heruntergeladenen Seiten</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Herunterladen von Videodaten</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Das kann sehr lange dauern</translation>
    </message>
</context>
</TS>
